/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "game.h"

font_t font;
primitive_t quad;

texture_t mom;
primitive_t cube;

bool gameInit(game_t *game) {
  // Init the game
  game->name = GAME_NAME;

  // Init the engine and the rendering pipeline
  engineInit(&game->engine, game);

  // Hand off to the poker logic.
  pokerInit(&game->poker);

  assetFontLoad(&font, "fonts/opensans/OpenSans-Bold.ttf", 64.0);

  char *text = "Ayy\nNice meme";
  fonttextinfo_t info = fontGetTextInfo(&font, text);
  fontmeasure_t *measure = fontTextMeasure(&font, text, &info);
  fontTextInitFromMeasure(&font, &quad, text, &info, measure);
  fontTextMeasureDispose(measure);

  quadInit(&cube, 0,  0,0,0,0,  923,576,1,1);
  assetTextureLoad(&mom, "cards_normal.png");

  return true;
}

bool gameUpdate(game_t *game, float platformDelta) {
  // Let the engine do its thing.
  engineUpdateStart(&game->engine, game, platformDelta);

  // Hand off to the poker logic
  shaderUse(&game->poker.shader);

  // cameraPerspective(&game->poker.camera, 45,
  //   game->engine.render.width/game->engine.render.height,
  //   0.01, 1000
  // );
  // cameraLookAt(&game->poker.camera, 300,300,300, 0,0,0);

  cameraOrtho(&game->poker.camera,
    0, game->engine.render.width,
    game->engine.render.height, 0,
    0.1, 1000
  );
  cameraLookAt(&game->poker.camera, 0,0,5, 0,0,-5);

  shaderUseCamera(&game->poker.shader, &game->poker.camera);

  shaderUseTexture(&game->poker.shader, &font.texture);
  shaderUsePosition(&game->poker.shader, 0,0,0, 0,0,0);
  primitiveDraw(&quad, 0, -1);

  // shaderUseTexture(&game->poker.shader, &mom);
  // shaderUsePosition(&game->poker.shader, 0,0,0, 0,0,0);
  // primitiveDraw(&cube, 0, -1);

  // pokerUpdate(&game->poker, &game->engine.render);

  // Hand back to the engine.
  return engineUpdateEnd(&game->engine, game);
}

void gameDispose(game_t *game) {
  pokerDispose(&game->poker);
  engineDispose(&game->engine, game);
}