/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "poker.h"

void pokerInit(poker_t *poker) {
  // Load the main shader
  assetShaderLoad(&poker->shader,
    "shaders/textured.vert", "shaders/textured.frag"
  );

  // Initialize the render stuffs.
  pokerWorldInit(poker);
  pokerCardInit(poker);
  pokerPlayerInit(poker);

  // Hand over to the deal for the first time.
  pokerMatchInit(poker);
}

void pokerUpdate(poker_t *poker, render_t *render) {
  // Game Logic
  switch(poker->round) {
    case POKER_ROUND_MATCH:
      pokerMatchUpdate(poker);
      break;
    default:
      break;
  }
  
  // Rendering
  cameraPerspective(&poker->camera, 20,render->width/render->height,0.001,1000);
  shaderUse(&poker->shader);
  shaderUseCamera(&poker->shader, &poker->camera);

  pokerWorldRender(poker);
  for(uint8_t pi = 0; pi < POKER_PLAYER_COUNT; pi++) {
    uint8_t seat = pokerPlayerGetSeatForPlayer(pi);
    pokerPlayerRender(poker, poker->players + pi, seat);
  }
}

void pokerDispose(poker_t * poker) {
  pokerWorldDispose(poker);
  shaderDispose(&poker->shader);
}